function varargout = callbacks(varargin)
% CALLBACKS M-file for callbacks.fig
%      CALLBACKS, by itself, creates a new CALLBACKS or raises the existing
%      singleton*.
%
%      H = CALLBACKS returns the handle to a new CALLBACKS or the handle to
%      the existing singleton*.
%
%      CALLBACKS('Property','Value',...) creates a new CALLBACKS using the
%      given property value pairs. Unrecognized properties are passed via
%      varargin to callbacks_OpeningFcn.  This calling syntax produces a
%      warning when there is an existing singleton*.
%
%      CALLBACKS('CALLBACK') and CALLBACKS('CALLBACK',hObject,...) call the
%      local function named CALLBACK in CALLBACKS.M with the given input
%      arguments.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help callbacks

% Last Modified by GUIDE v2.5 26-Jun-2002 18:30:10

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @callbacks_OpeningFcn, ...
                   'gui_OutputFcn',  @callbacks_OutputFcn, ...
                   'gui_LayoutFcn',  [], ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before callbacks is made visible.
function callbacks_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   unrecognized PropertyName/PropertyValue pairs from the
%            command line (see VARARGIN)

% Choose default command line output for callbacks
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes callbacks wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = callbacks_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

function edit1_Callback(hObject, eventdata, handles)
% hObject    handle to edit1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of edit1 as text
%        str2double(get(hObject,'String')) returns contents of edit1 as a double
h_line = findobj(gcf, 'Type', 'line');
color_string = get(hObject, 'String');
color_value = str2num(color_string);
set(h_line, 'Color', color_value);